$!*************************************************************************
$!*                                                                       *
$!*  JUMP -- JUMP_STARTUP.COM                                             *
$!*                                                                       *
$!*************************************************************************
$!*  Author and Maintainer: Jonathan Ridler.                              *
$!*                                                                       *
$!*  This software is owned and maintained privately by the author,       *
$!*  Jonathan Ridler. It is NOT in any way produced, owned, supported,    *
$!*  maintained or endorsed by Hewlett Packard Pty Ltd or any of its      *
$!*  legal entities.                                                      *
$!*                                                                       *
$!*  Email: vmsjump@internode.on.net                                      *
$!*************************************************************************
$!*************************************************************************
$!***                                                                   ***
$!***                         LICENCE NOTICE                            ***
$!***                                                                   ***
$!***  This software is COPYRIGHT (c) 1993-2022 Jonathan Ridler.        ***
$!***  ALL RIGHTS RESERVED.                                             ***
$!***                                                                   ***
$!***  Please READ the file JUMP_LICENCE.TXT which contains the         ***
$!***  complete Licence and all conditions of use for JUMP.             ***
$!***                                                                   ***
$!***  NOTE: By using JUMP or any part of the JUMP distribution for     ***
$!***        any purpose, you are agreeing to all conditions of the     ***
$!***        JUMP licence.                                              ***
$!***                                                                   ***
$!*************************************************************************
$!*************************************************************************
$!
$!         ***************************************************
$!	   ***						   ***
$!         *** YOU MUST EDIT THIS FILE BEFORE USING IT !!! ***
$!	   ***						   ***
$!         ***************************************************
$!
$!-------------------------------------------------------------------------
$!  This file is a template STARTUP file for JUMP. Edit the file to your
$!  requirements and then include it in your site-specific startup, if you
$!  wish to do so.
$!
$!  History:
$!	01-Feb-2012     JER     New for JUMP V6.0.
$!	03-Feb-2012     JER     JUMP V6.1.
$!	28-Aug-2012	JER	Added JUMP_USER_DEBUG_OPCOM logical name.
$!*************************************************************************
$
$ on ERROR  then  CONTINUE
$
$ say := write SYS$OUTPUT
$
$ say "%JUMP-I-STARTING, Starting JUMP ..."
$ 
$ install   := $SYS$SYSTEM:INSTALL
$ authorize := $SYS$SYSTEM:AUTHORIZE
$
$ jump_image := SYS_SYSTEM:JUMP.EXE		!!! <<<==== SITE-SPECIFIC
$
$ if f$search ("''JUMP_IMAGE'") .eqs. ""
$ then
$   say "%JUMP-E-EXENOTFOU, JUMP image file not found"
$ else
$   set file 'jump_image' /log /protection=(S:RWED,O:RWED,G,W:E)
$   set file 'jump_image' /log /owner=SYSTEM
$   if $status .eq. %X10778072
$   then
$     say "%JUMP-W-IMAGINST, JUMP appears to be INSTALLed"
$     say "-JUMP-I-RETRYSET, Use INSTALL REMOVE and retry the SET owner command"
$   endif
$ endif
$
$!.........................................................................
$
$! Define all required, or desired optional, logical names.
$! It is not necessary to define the logical names below if those logical
$! names have default values and you want to use their default values.
$! See the JUMP help documentation for details.
$
$!!! define /system /executive JUMP_ACCESS_LIST SYS_MANAGER:JUMP_ACCESS.DAT
$
$!!! define /system /executive JUMP_ACME_AGENT_NAME LDAP
$
$!!! define /system /executive JUMP_AUDIT_TRAIL SYS_MANAGER:JUMP_AUDIT.DAT
$
$!!! define /system /executive JUMP_CHAIN TRUE
$
$!!! define /system /executive JUMP_DOUBLE_CHECK TRUE
$
$!!! define /system /executive JUMP_HELPLIB SYS_HELP:PUBHELP.HLB
$
$!!! define /system /executive JUMP_MINOR_PRIVS "NETMBX TMPMBX"
$
$!!! define /system /executive JUMP_NOTIFY_MAILLIST SYSTEM
$
$!!! define /system /executive JUMP_OPER_CLASSES CENTRAL
$
$!!! define /system /executive JUMP_SECURE_DIR SYS_MANAGER:
$
$!!! define /system /executive JUMP_SECURE_MODE FALSE
$
$!!! define /system /executive JUMP_SELF TRUE
$
$!!! ***  If you wish to use the JUMP individual Single Command  ***
$!!! *** feature, define the logical names you want to use here. ***
$!!! define /system /executive JUMP_SINGLE_CMD_<number> "<command>"
$!!! define /system /executive JUMP_SINGLE_CMD_<number> "<command>"
$!!! define /system /executive JUMP_SINGLE_CMD_<number> "<command>"
$
$!!! define /system /executive JUMP_USER_DEBUG_OPCOM TRUE
$
$!!! define /system /executive JUMP_USER_DIR SYS$LOGIN:
$
$!.........................................................................
$
$! Create the JUMP audit trail file if it does not exist.
$
$ if f$trnlnm ("JUMP_AUDIT_TRAIL","LNM$SYSTEM_TABLE","EXECUTIVE") .eqs. ""
$ then
$   say "%JUMP-W-AUDNOLNM, JUMP_AUDIT_TRAIL logical name is not defined"
$   say "-JUMP-I-CHECKAUD, Ensure the Audit Trail file exists"
$ else
$   if f$search ("JUMP_AUDIT_TRAIL") .eqs. ""
$   then
$     say "%JUMP-E-AUDNOTFOU, JUMP_AUDIT_TRAIL logical name defined, " + -
          "but file not found"
$     say "-JUMP-I-CHKFIXAUD, Check the logical name and ensure the Audit " + -
	  "Trail file exists"
$     say "%JUMP-I-CRENEWAUD, Creating new Audit Trail file in defined location"
$     create /log JUMP_AUDIT_TRAIL
$   endif
$   set file JUMP_AUDIT_TRAIL /owner=SYSTEM /protection=(S:RWED,O:RWED,G,W)
$ endif
$
$! Check that the JUMP access list file exists if the logical name is defined.
$
$ if f$trnlnm ("JUMP_ACCESS_LIST","LNM$SYSTEM_TABLE","EXECUTIVE") .eqs. ""
$ then
$   say "%JUMP-I-ACCNOLNM, JUMP_ACCESS_LIST logical name is not defined"
$   say "-JUMP-I-CHECKACC, Ensure the Access List file exists, if it is required"
$ else
$   if f$search ("JUMP_ACCESS_LIST") .eqs. ""
$   then
$     say "%JUMP-E-ACCNOTFOU, JUMP_ACCESS_LIST logical name defined, " + -
          "but file not found"
$     say "-JUMP-I-CHECKACC,  Check the logical name and ensure the Access " + -
	  "List file exists"
$   else
$     set file JUMP_ACCESS_LIST /owner=SYSTEM /protection=(S:RWED,O:RWED,G,W)
$   endif
$ endif
$
$! Create the JUMP secure directory if it does not exist.
$
$ if f$trnlnm ("JUMP_SECURE_DIR","LNM$SYSTEM_TABLE","EXECUTIVE") .nes. ""
$ then
$   say "%JUMP-I-CHKFIXSEC, JUMP_SECURE_DIR logical name is defined -- " + -
	"ensuring Secure Directory exists in defined location"
$   create /directory /log JUMP_SECURE_DIR	! No problem if it already exists
$!!!  *** MUST EDIT THIS NEXT LINE *** ...
$!!!   set file <JUMP_SECURE_DIR_spec> /owner=SYSTEM /protection=(S:RWED,O:RWED,G,W)
$ endif
$
$!.........................................................................
$
$! Create the JUMP_ACCESS Rightslist identifier -- the actual value is
$! irrelevant. If the JUMP_ACCESS Rightslist identifier is not used,
$! JUMP_DOUBLE_CHECK *must* be defined to be "FALSE".
$
$!!! if f$identifier ("JUMP_ACCESS","NAME_TO_NUMBER") = 0 then -
$!!!      authorize ADD /IDENTIFIER JUMP_ACCESS
$
$! Install the JUMP image with (or without) privileges, as required
$
$!!! say "%JUMP-I-INSTIMAG, Installing JUMP image"
$!!! install ADD 'jump_image' /OPEN /HEADER /SHARED -
$!!!          /PRIVILEGE=(CMEXEC,CMKRNL,DETACH,SYSNAM,SYSPRV)
$
$!.........................................................................
$
$ say "%JUMP-I-STARTED, JUMP startup finished."
$
$ EXIT
